@@ -1,10 +1,10 @@
 # coding: utf-8
 
-from roundtrip import dedent
+from roundtrip import dedent  # type: ignore
 
 
 class TestDedent:
-    def test_start_newline(self):
+    def test_start_newline(self) -> None:
         # fmt: off
         x = dedent("""
         123
@@ -13,7 +13,7 @@ class TestDedent:
         # fmt: on
         assert x == '123\n  456\n'
 
-    def test_start_space_newline(self):
+    def test_start_space_newline(self) -> None:
         # special construct to prevent stripping of following whitespace
         # fmt: off
         x = dedent("   " """
@@ -22,7 +22,7 @@ class TestDedent:
         # fmt: on
         assert x == '123\n'
 
-    def test_start_no_newline(self):
+    def test_start_no_newline(self) -> None:
         # special construct to prevent stripping of following whitespac
         x = dedent("""\
         123
@@ -30,20 +30,20 @@ class TestDedent:
         """)
         assert x == '123\n  456\n'
 
-    def test_preserve_no_newline_at_end(self):
+    def test_preserve_no_newline_at_end(self) -> None:
         x = dedent("""
         123""")
         assert x == '123'
 
-    def test_preserve_no_newline_at_all(self):
+    def test_preserve_no_newline_at_all(self) -> None:
         x = dedent("""\
         123""")
         assert x == '123'
 
-    def test_multiple_dedent(self):
+    def test_multiple_dedent(self) -> None:
         x = dedent(
             dedent("""
         123
-        """)
+        """),
         )
         assert x == '123\n'
